RE: [Unattended] Some ideas from the new guy

2004-03-23 Thread Jonas Olsson
On Tue, 23 Mar 2004, Matthew Palmer wrote:

> You may or may not be aware of the existence of a nice little webapp called
> IRM.  It can do machine, user, licence, networking tracking, (and soon
> peripherals).  My "dream" (called that because I want to do it but have no
> clear plan on when or how) is to integrate Unattended and IRM, as follows:

This IRM application sounds interesting. Would you happen to have a link
to its homepage? The only matching entry I can find on Freshmeat is
http://www.stackworks.net/view.php/irm/index.html.


  /Jonas


---
This SF.Net email is sponsored by: IBM Linux Tutorials
Free Linux tutorial presented by Daniel Robbins, President and CEO of
GenToo technologies. Learn everything from fundamentals to system
administration.http://ads.osdn.com/?ad_id=1470&alloc_id=3638&op=click
___
unattended-info mailing list
[EMAIL PROTECTED]
https://lists.sourceforge.net/lists/listinfo/unattended-info


Re: [Unattended] Obtaining values from a spreadsheet

2004-03-23 Thread Russell Smith
This is a helpful and useful Idea, however I'm not 100% sure making it default 
is easiest/best.  Having a set of configs that people can just copy in to 
make things work would probably be helpful.  But Others, like myself will 
want to mix and match.

Most if not all of the licenses for XP i Use are OEM, so I like to keep the 
license XP license in the hardware section, with the computer.

I have adjusted Drivers, so you can specify the drivers location, and not 
download 2G of Drivers onto every machines.

Has anybody successfully done this with other applications?
eg putting different serial numbers into a setup.iss or autoit script to 
install an application with different numbers on different computers.  I run 
into this all the time.  And am not sure if it's easy/possible.  Could all 
the Unattended libs be used to parse the setup.iss file too?

Looks like more perl learning if that's possible. :)

Regards

Russell Smith


---
This SF.Net email is sponsored by: IBM Linux Tutorials
Free Linux tutorial presented by Daniel Robbins, President and CEO of
GenToo technologies. Learn everything from fundamentals to system
administration.http://ads.osdn.com/?ad_id=1470&alloc_id=3638&op=click
___
unattended-info mailing list
[EMAIL PROTECTED]
https://lists.sourceforge.net/lists/listinfo/unattended-info


Re: [Unattended] Obtaining values from a spreadsheet

2004-03-23 Thread Russell Smith
Also out of interest, and maybe a little boasting. :(

I have attached the config.pl I use as an example also.  I am no brilliant 
Perl coders, but this functions quite well.  I have also changed the WinMedia 
included so I can specific the place to check drivers for.$u->{'_meta'}->{'drivers_dir'} = 'none';

# Function to set Driver Paths for Each Machine
# Drivers Should be stored in Z:\Drivers\\
# all drivers for a given machine/type should be stored here.
# drivers will be copied to machines before installation
sub oem_pnp_dirs ($;$) {
my $media_obj = Unattend::WinMedia->new ($u->{'_meta'}->{'OS_media'});
my $oem_system_dir = "z:\\Drivers\\".$u->{'_meta'}->{'drivers_dir'};

print "Looking for drivers under $oem_system_dir...\n";

my @ret = $media_obj->oem_pnp_dirs (1, $oem_system_dir);
#my @ret = $media_obj->oem_pnp_dirs (1);

$verbose && scalar @ret == 0
and print "...no driver directories found.\n";

foreach my $dir (@ret) {
push @selecteddirs, "Drivers\\".$dir;
}

my $ret = join ';', @selecteddirs;
return $ret;
}

#Open PC file and find The Current PC as its parameters
# File format Tab seperated list
#	Computer Name		MYCOMPUTER
#	MAC Address		4455AACC
#	Operating System	
#	Software Script		top (runs top.bat to install apps)
#	Driver Directory	IBM6288
#	OEM Product Key		X-X-X-X-X

open(pcs, 'z:\\site\\pc');

while() {
chop;
($image,$pc,$mac,$os,$software,$drivers,$productkey) = split(/\t/);

if ( $mac eq $u->{'_meta'}->{'macaddr'}) {
	$u->{'_meta'}->{'OS'} = $os;
	$u->{'_meta'}->{'top'} = $software.".bat";
	$u->{'UserData'}->{'ComputerName'} = $pc;
	$u->{'_meta'}->{'drivers_dir'} = $drivers;
	$u->{'UserData'}->{'ProductKey'} = $productkey;
last;
}
}

if ( $mac != $u->{'_meta'}->{'macaddr'}) {
print $u->{'_meta'}->{'macaddr'};
#my $newpcname = simple_q ("Enter PC's Name: ");
#my $newpcmac = get_value('_meta','macaddr');
#open(NEWPC,">>z:\\tmp\\newpc") || die ("Cannot Add New PC to File");
#print NEWPC "$newpcname\t$newpcmac\n";
#close NEWPC;

die "Added to the new list, please configure it and restart";
# I should ask questions here, and get it added to the list
# of newpc's like in the old version.
}

#Make boot mac address, strip leading 0's from bytes, last 8 bytes.
#00AABB0DCCE0 -> 0AABBDCCE0 -> ABBDCCE0

my $mac = $u->{'_meta'}->{'macaddr'};
my $newmac = "";
for ($i=0; $i<6 ;$i++) { 
$j=substr($mac,($i*2),2);
if (substr($j,0,1) eq "0") {
	$j=substr($j,1);
}
$newmac = $newmac . $j;
}
$newmac = substr($newmac,-8);

#Now set doit to tell machine to boot from local machine
#my $copying = "copy /Y z:\\tftpboot\\pxelinux.cfg\\hdd z:\\tftpboot\\pxelinux.cfg\\$newmac;";
my $copying = "copy /Y z:\\tftpboot\\pxelinux.cfg\\hdd z:\\tftpboot\\pxelinux.cfg\\$newmac;";

# Set doit.bat to copy drivers to machine to install.
$copying .= "mkdir C:\\Drivers;xcopy /Y /S z:\\Drivers\\$drivers c:\\Drivers\\;";


$u->{'_meta'}->{'doit_cmds'} = $copying . $u->{'_meta'}->{'doit_cmds'};

# Set PNP drivers.
$u->{'Unattended'}->{'OemPnPDriversPath'} = \&oem_pnp_dirs;
$u->{'_meta'}->{'autolog'} = 'autolog.pl --logon=0';

rtlnet  LAB1PCA06   0020ED895A3CwinxpoemFbase   build03 
X-X-X-X-X
rtlnet  LAB1PCD02   0020ED896F12winxpoemFvideo  build03 
X-X-X-X-X
e100net SPECEDPCA5  0002B3EB2A3FwinxpoemFbase   lib04   
X-X-X-X-X
e100net LIB1PCA03   0002B3EB2C60winxpoemFliblib04   
X-X-X-X-X
--- unattended/install/lib/Unattend/WinMedia.pm	2004-03-16 11:56:13.0 +1100
+++ lib/Unattend/WinMedia.pm	2004-03-16 13:38:28.0 +1100
@@ -272,9 +272,12 @@
 sub oem_pnp_dirs ($;$) {
 my Unattend::WinMedia $self = shift;
 my $verbose = shift;
+my $oem_system_dir = shift;
 
-my $oem_system_dir =
+if (!$oem_system_dir) {
+$oem_system_dir =
 $file_spec->catdir ($self->path (), 'i386', '$oem$', '$1');
+}
 
 $verbose
 and print "Looking for drivers under $oem_system_dir...\n";


[Unattended] RE: IRM [was: Some ideas from the new guy]

2004-03-23 Thread Matthew Palmer
> On Tue, 23 Mar 2004, Matthew Palmer wrote:
>
> > You may or may not be aware of the existence of a nice
> little webapp called
> > IRM.  It can do machine, user, licence, networking
> tracking, (and soon
> > peripherals).  My "dream" (called that because I want to do
> it but have no
> > clear plan on when or how) is to integrate Unattended and
> IRM, as follows:
>
> This IRM application sounds interesting. Would you happen to
> have a link
> to its homepage? The only matching entry I can find on Freshmeat is
> http://www.stackworks.net/view.php/irm/index.html.

That be the one - or at least it's current location.  Keeps moving every few
months.

Or, if you're running Debian, you can apt-get install irm.

- Matt



---
This SF.Net email is sponsored by: IBM Linux Tutorials
Free Linux tutorial presented by Daniel Robbins, President and CEO of
GenToo technologies. Learn everything from fundamentals to system
administration.http://ads.osdn.com/?ad_id=1470&alloc_id=3638&op=click
___
unattended-info mailing list
[EMAIL PROTECTED]
https://lists.sourceforge.net/lists/listinfo/unattended-info


RE: [Unattended] RE: IRM [was: Some ideas from the new guy]

2004-03-23 Thread Don Morrison
Thanks for the feedback Matt.  I checked out IRM a couple of weeks ago as I
was ramping up for my inventory project.  I still haven't selected one I
wanted to use.  I found myself being drawn to Brage - CM
(http://brage-cm.sourceforge.net/).  I enjoy the profiles and events
portion.  Of course, if we did it right, Unattended wouldn't care what you
were running in the background.  Perhaps having a couple of different
systems tested wouldn't be a bad thing.

Don

> On Tue, 23 Mar 2004, Matthew Palmer wrote:
>
> > You may or may not be aware of the existence of a nice
> little webapp called
> > IRM.  It can do machine, user, licence, networking
> tracking, (and soon
> > peripherals).  My "dream" (called that because I want to do
> it but have no
> > clear plan on when or how) is to integrate Unattended and
> IRM, as follows:
>
> This IRM application sounds interesting. Would you happen to have a 
> link to its homepage? The only matching entry I can find on Freshmeat 
> is http://www.stackworks.net/view.php/irm/index.html.

That be the one - or at least it's current location.  Keeps moving every few
months.

Or, if you're running Debian, you can apt-get install irm.

- Matt



---
This SF.Net email is sponsored by: IBM Linux Tutorials
Free Linux tutorial presented by Daniel Robbins, President and CEO of
GenToo technologies. Learn everything from fundamentals to system
administration.http://ads.osdn.com/?ad_id=1470&alloc_id=3638&op=click
___
unattended-info mailing list
[EMAIL PROTECTED]
https://lists.sourceforge.net/lists/listinfo/unattended-info


[Unattended] JRE2 Install command switch

2004-03-23 Thread Don Morrison
Hey guys,

I was having a problem with the JRE2 install this morning and figured out it
was the missing space before the "/qb" switch [This was been fixed in CVS by
slords on March 21 :)].  But as I was looking at the Java Silent
Installation doc I noticed the switch should be /qn.  I confirmed that on
the InstallShield site (http://support.installshield.com/).  I tested the
install with both and it doesn't seem to effect the end result of having the
plugins registered but it does effect the "noise" level of the installation.
With /qb there is still a status window displayed while using /qn results in
absolute zen-like silence.

So my todo line in sun-jre.bat looks like this now:

todo.pl "%Z%\packages\j2re-1_4_2_03-windows-i586-p.exe /s /v\ "/qn
IEXPLORER=1 MOZILLA=1 NETSCAPE6=1 REBOOT=ReallySuppress\""

I have attached the diff of the orig and my update under cygwin, does that
help you out at all?

Thanks.
Don



sun-jre.bat.diff
Description: Binary data


RE: [Unattended] JRE2 Install command switch

2004-03-23 Thread Don Morrison
"was been fixed"??  Oh yeah!  I'm going home ...

-Original Message-
From: Don Morrison [mailto:[EMAIL PROTECTED] 
Sent: Tuesday, March 23, 2004 5:29 PM
To: Unattended Info ([EMAIL PROTECTED])
Subject: [Unattended] JRE2 Install command switch

Hey guys,

I was having a problem with the JRE2 install this morning and figured out it
was the missing space before the "/qb" switch [This was been fixed in CVS by
slords on March 21 :)].  But as I was looking at the Java Silent
Installation doc I noticed the switch should be /qn.  I confirmed that on
the InstallShield site (http://support.installshield.com/).  I tested the
install with both and it doesn't seem to effect the end result of having the
plugins registered but it does effect the "noise" level of the installation.
With /qb there is still a status window displayed while using /qn results in
absolute zen-like silence.

So my todo line in sun-jre.bat looks like this now:

todo.pl "%Z%\packages\j2re-1_4_2_03-windows-i586-p.exe /s /v\ "/qn
IEXPLORER=1 MOZILLA=1 NETSCAPE6=1 REBOOT=ReallySuppress\""

I have attached the diff of the orig and my update under cygwin, does that
help you out at all?

Thanks.
Don



---
This SF.Net email is sponsored by: IBM Linux Tutorials
Free Linux tutorial presented by Daniel Robbins, President and CEO of
GenToo technologies. Learn everything from fundamentals to system
administration.http://ads.osdn.com/?ad_id=1470&alloc_id=3638&op=click
___
unattended-info mailing list
[EMAIL PROTECTED]
https://lists.sourceforge.net/lists/listinfo/unattended-info


Re: [Unattended] JRE2 Install command switch

2004-03-23 Thread Adam Peart
At 08:29 PM 03/23/2004, you wrote:
I tested the
install with both and it doesn't seem to effect the end result of having the
plugins registered but it does effect the "noise" level of the installation.
With /qb there is still a status window displayed while using /qn results in
absolute zen-like silence.
And here I like seeing the progress bar' because it tells me the computer 
is doing something and isn't frozen, as well as how it's going.  Just my 
two cents.



---
This SF.Net email is sponsored by: IBM Linux Tutorials
Free Linux tutorial presented by Daniel Robbins, President and CEO of
GenToo technologies. Learn everything from fundamentals to system
administration.http://ads.osdn.com/?ad_id=1470&alloc_id=3638&op=click
___
unattended-info mailing list
[EMAIL PROTECTED]
https://lists.sourceforge.net/lists/listinfo/unattended-info


RE : [Unattended] Unattended authentication issues....

2004-03-23 Thread Sylvain Faivre

> -Message d'origine-
> De : [EMAIL PROTECTED] 
> [mailto:[EMAIL PROTECTED] De la 
> part de Patrick J. LoPresti
> Envoyé : mardi 23 mars 2004 01:59
> À : Jeff Black
> Cc : [EMAIL PROTECTED]
> Objet : Re: [Unattended] Unattended authentication issues
> 
> 
> "Jeff Black" <[EMAIL PROTECTED]> writes:
> 
> > > Add the folowing lines to the _meta tag in your unattend.txt
> > > 
> > > z_user = domainname\userid
> > 
> > Sounds like cheating to me :)
> 
> True, but it should serve as a workaround.
> 
> > On the upside the Linux Boot Disk took domainname\jmblack and seems
> > to be 'doing the right thing' I'm still a little unclear as to why
> > the DOS boot disk fails when given the same authentication.
> 
> The real question is why the DOS "net use" command is able to map the
> drive at all without a domain.
> 
> I do not really understand DOS networking...
> 
> Anyway, I have added code to make z_user default to DOMAIN\username in
> the next release.  (Where DOMAIN is [Identification]/JoinDomain, if it
> exists, and username is the value provided to the boot disk.)
> 
>  - Pat
> 

Hmm, maybe an option to enable/disable this domain thing would be useful, because some 
people (like me ;-) ) created a user on the file server to map the drive, and not on 
the domain. So this would break authentification on my setup.

Sylvain.



---
This SF.Net email is sponsored by: IBM Linux Tutorials
Free Linux tutorial presented by Daniel Robbins, President and CEO of
GenToo technologies. Learn everything from fundamentals to system
administration.http://ads.osdn.com/?ad_id70&alloc_id638&op=click
___
unattended-info mailing list
[EMAIL PROTECTED]
https://lists.sourceforge.net/lists/listinfo/unattended-info


RE: [Unattended] No system disk or disk error

2004-03-23 Thread DE-LOS-SANTOS,ORIOL (HP-Spain,ex1)
I finally solved this issue disabling the legacy USB emulation as described
in the link you sent me.

Thanks again
Oriol de los Santos

> -Original Message-
> From: DE-LOS-SANTOS,ORIOL (HP-Spain,ex1) 
> [mailto:[EMAIL PROTECTED] 
> Sent: Monday, March 22, 2004 5:04 PM
> To: 'Patrick J. LoPresti'; DE-LOS-SANTOS,ORIOL (HP-Spain,ex1)
> Cc: [EMAIL PROTECTED]
> Subject: RE: [Unattended] No system disk or disk error
> 
> 
> The version of the unattended is 3.2
> 
> Can I just take the linux boot disk and keep everything else the same?
> 
> Thanks
> Oriol
> 
> 
> 
> > -Original Message-
> > From: Patrick J. LoPresti [mailto:[EMAIL PROTECTED]
> > Sent: Monday, March 22, 2004 2:19 PM
> > To: DE-LOS-SANTOS,ORIOL (HP-Spain,ex1)
> > Cc: [EMAIL PROTECTED]
> > Subject: Re: [Unattended] No system disk or disk error
> > 
> > 
> > "DE-LOS-SANTOS,ORIOL (HP-Spain,ex1)"
> > <[EMAIL PROTECTED]> writes:
> > 
> > > We have been using Unattended for some time now without major
> > > problems. Unfortunately we are now having to install 
> > "Toshiba Techra
> > > S1" laptops. After we boot from the network and type "INST"
> > to start
> > > the installation  we get the followin error.
> > > 
> > > "Non system disk or disk error"
> > > 
> > > What can this be?
> > 
> > Some incompatibility between memdisk and the Tecra, perhaps.
> > 
> > What version of Unattended?
> > 
> > This might be relevant:
> > 
>  
http://www.mail-archive.com/[EMAIL PROTECTED]/msg00521.h
tml

Finally, you might try the Linux boot disk.

 - Pat


---
This SF.Net email is sponsored by: IBM Linux Tutorials
Free Linux tutorial presented by Daniel Robbins, President and CEO of GenToo
technologies. Learn everything from fundamentals to system
administration.http://ads.osdn.com/?ad_id=1470&alloc_id=3638&op=click
___
unattended-info mailing list [EMAIL PROTECTED]
https://lists.sourceforge.net/lists/listinfo/unattended-info


---
This SF.Net email is sponsored by: IBM Linux Tutorials
Free Linux tutorial presented by Daniel Robbins, President and CEO of
GenToo technologies. Learn everything from fundamentals to system
administration.http://ads.osdn.com/?ad_id=1470&alloc_id=3638&op=click
___
unattended-info mailing list
[EMAIL PROTECTED]
https://lists.sourceforge.net/lists/listinfo/unattended-info


AW: RE: AW: Re: [Unattended] Networking problem

2004-03-23 Thread m . frei
I managed to get it correctly unpacked using Winzip at the end by setting
the switch in Winzip. Most things seem to work with the new version of Unattend
and the Linux boot disk. There is something though, which wasn't a problem
before. With version 3.5 it was possible to use file and directory names
larger than the 8.3 DOS standard. That doesn't seem to work anymore under
version 4.0.

Anyway, thanks for your help

- M.Frei


>-- Originalnachricht --
>From: "Stephan Lampe [ITXP]" <[EMAIL PROTECTED]>
>To: "'Patrick J. LoPresti'" <[EMAIL PROTECTED]>
>Cc: <[EMAIL PROTECTED]>
>Subject: RE: AW:  Re: [Unattended] Networking problem
>Date: Sat, 20 Mar 2004 16:46:56 +0100
>
>
>> >
>> > done loading ide-disk
>> > :bad interpreter: no such file or directorysh
>>
>> RHH!!!
>>
>> The problem here is that your
>> Z:\linuxaux\etc\make-blkdev-nodes (or some other script) has
>> DOS-style line endings.  Out of curiosity, how did you unpack
>> it?  Wait, let me guess: WinZip on Windows?
>>
>
>Seen that also, extracting with winRar 3.30.
>Just to offer m.frei a way out of your 'rage' ;)
>
>Good luck with your cold and new friend Advil.
>
>
>
>
 



---
This SF.Net email is sponsored by: IBM Linux Tutorials
Free Linux tutorial presented by Daniel Robbins, President and CEO of
GenToo technologies. Learn everything from fundamentals to system
administration.http://ads.osdn.com/?ad_id70&alloc_id638&op=click
___
unattended-info mailing list
[EMAIL PROTECTED]
https://lists.sourceforge.net/lists/listinfo/unattended-info


[Unattended] Obtaining values from a spreadsheet

2004-03-23 Thread Patrick J. LoPresti
In Unattended 4.0b, we added some new files to the install/site
directory:

hardware.csv
software.csv
sample-config.pl

The file "sample-config.pl" is the actual config.pl which Shad uses.
It automatically sets several installation parameters based on the
values in two comma-separated-value (CSV) spreadsheets.

We are thinking about making this behavior, or something like it, the
default for the next release.  So this message is both a description
of the implementation and a request for feedback on it.

The first spreadsheet, hardware.csv, has fields for MAC address,
computer name, "owner" (aka. [UserData]/FullName), and organization.
These are fairly self-explanatory...  If the MAC address of the system
matches a line in the spreadsheet, the remaining fields will be used
to fill in the corresponding unattend.txt parameters.  In other words,
the MAC is the "index key" for this spreadsheet.

The second spreadsheet, software.csv, lists software licenses.  It has
fields for "owner", "software" (the name of the software product), the
license key, and the local admin password.  The "owner" and "software"
keys are the index keys for this spreadsheet.  The "software" field
must match the operating system name (e.g., "Windows XP
Professional").  The "owner" field must match either the MAC address,
user name, computer name, or organization of the machine.  If a match
is found, the license key and administrator password are set from the
values in the spreadsheet.

The idea is that a software license is "owned" by a machine (MAC
address or name), or by a user, or by an organization (think volume
licenses).

I am thinking of ways to generalize this to use a key other than MAC
address, like (say) the Dell service tag.  More on that later.  But
the implementation described here would still be the default.

What do you folks think?

(By the way, it is a fully functioning implementation.  If you want to
try it out, just copy sample-config.pl to Z:\site\config.pl.)

 - Pat


---
This SF.Net email is sponsored by: IBM Linux Tutorials
Free Linux tutorial presented by Daniel Robbins, President and CEO of
GenToo technologies. Learn everything from fundamentals to system
administration.http://ads.osdn.com/?ad_id=1470&alloc_id=3638&op=click
___
unattended-info mailing list
[EMAIL PROTECTED]
https://lists.sourceforge.net/lists/listinfo/unattended-info


Re: [Unattended] Using todo.pl outside building the machine

2004-03-23 Thread Patrick J. LoPresti
"Norström, Daniel" <[EMAIL PROTECTED]> writes:

> Hi Shad and Pat,
>  
> I would need to be able to use todo.pl outside building the
> machine. For security reasons, I'm building the machines on a
> separate network and what I would like is to have the possibility to
> install applications on top in the "real" environment.
>  
> What I've done:
>  
> I've copied the todo.pl file over from the \BIN folder to a new
> server with the applications and script I would like to install, but
> when posting jobs to the script it complains over that is hasn't got
> the connection to the Z:\ Drive.  Out of my understanding I don't
> need to have any contact to the Z:\ drive server (except for the
> todo.pl file) since I have the drive where I would like to install
> the applications from mapped from the logon script.

Which drive letter are you using?

The scripts we provide assume %Z% holds the drive letter.  If you want
to use, say, the X: drive instead, you would put this in
C:\netinst\permcreds.bat:

set Z=X:

If you are using just your own scripts which do not refer to %Z%, then
you are right, this should not be necessary...

> the error code is 
> Unable to GetUNCName for Z:: This network connection does not exist at
> P:\scripts\files\Bin\todo.pl line 185.

...but right now, todo.pl attempts to locate the UNC path for the Z:
drive (as defined by the %Z% variable), so that it can set %Z_PATH%,
which some of our scripts also use.

In addition to causing your problem, this prevents %Z% from being a
local drive.  This in turn gets in the way of (say) using a DVD-ROM
for installation.  So I have fixed it in the next release.

Patch for todo.pl is appended.

 - Pat


--- todo.pl.~1.32.~ 2004-01-16 15:02:16.0 -0500
+++ todo.pl 2004-03-23 14:21:11.0 -0500
@@ -266,9 +266,12 @@
 return $lang_table{$langid};
 }
 
-# Get the UNC path for a networked drive.
+# For input letter X, return the UNC path to which X: is connected.
+# If X is a not a networked drive, return "X:".
+use constant ERROR_NOT_CONNECTED => 2250;
 sub get_drive_path ($) {
 my ($drive) = @_;
+my $ret;
 
 $drive =~ /^[a-z]:?$/i
 or die "Invalid drive specification $drive";
@@ -277,10 +280,18 @@
 $drive =~ /:$/
 or $drive .= ':';
 
-my $unc_name;
-Win32::NetResource::GetUNCName ($unc_name, $drive)
-or die "Unable to GetUNCName for $drive: $^E";
-return $unc_name;
+if (Win32::NetResource::GetUNCName ($ret, $drive)) {
+# all done
+}
+elsif ($^E == ERROR_NOT_CONNECTED) {
+# Not a network drive, so just return the drive letter itself.
+$ret = $drive;
+}
+else {
+die "Unable to GetUNCName for $drive: $^E";
+}
+
+return $ret;
 }
 
 # Set up console for single-character input and autoflush output.


---
This SF.Net email is sponsored by: IBM Linux Tutorials
Free Linux tutorial presented by Daniel Robbins, President and CEO of
GenToo technologies. Learn everything from fundamentals to system
administration.http://ads.osdn.com/?ad_id70&alloc_id638&op=click
___
unattended-info mailing list
[EMAIL PROTECTED]
https://lists.sourceforge.net/lists/listinfo/unattended-info


Re: [Unattended] Note on Samba 3 problem

2004-03-23 Thread Patrick J. LoPresti
Mark Pavlichuk <[EMAIL PROTECTED]> writes:

>   Samba 3 has a new option (called "unix extensions") which should
> be turned off if you're using the Linux boot disk.  If this option
> is switched on (which it is by default, at least on Debian) any
> symbolic links on a Samba share accessed by a samba client won't be
> resolved on the server but locally which will probably cause scripts
> to fail.

Added to .  Thank you!

 - Pat


---
This SF.Net email is sponsored by: IBM Linux Tutorials
Free Linux tutorial presented by Daniel Robbins, President and CEO of
GenToo technologies. Learn everything from fundamentals to system
administration.http://ads.osdn.com/?ad_id=1470&alloc_id=3638&op=click
___
unattended-info mailing list
[EMAIL PROTECTED]
https://lists.sourceforge.net/lists/listinfo/unattended-info


Re: AW: RE: AW: Re: [Unattended] Networking problem

2004-03-23 Thread Patrick J. LoPresti
[EMAIL PROTECTED] writes:

> There is something though, which wasn't a problem before. With
> version 3.5 it was possible to use file and directory names larger
> than the 8.3 DOS standard. That doesn't seem to work anymore under
> version 4.0.

Could you be more specific?  Which file and directory names do you
mean, exactly?

 - Pat


---
This SF.Net email is sponsored by: IBM Linux Tutorials
Free Linux tutorial presented by Daniel Robbins, President and CEO of
GenToo technologies. Learn everything from fundamentals to system
administration.http://ads.osdn.com/?ad_id=1470&alloc_id=3638&op=click
___
unattended-info mailing list
[EMAIL PROTECTED]
https://lists.sourceforge.net/lists/listinfo/unattended-info


Re: [Unattended] JRE2 Install command switch

2004-03-23 Thread Patrick J. LoPresti
Adam Peart <[EMAIL PROTECTED]> writes:

> And here I like seeing the progress bar' because it tells me the
> computer is doing something and isn't frozen, as well as how it's
> going.  Just my two cents.

Yeah, I like progress bars too, which is why I opted for /qb instead
of /qn like Sun documents.

The package is just an "InstallShield Basic MSI" installer:

  http://unattended.sourceforge.net/installers.html#ismsi

I am a little surprised that the space is required, since I am almost
certain I used to install the JRE without it...  I wonder what is
going on here, exactly.

But whatever works :-).

 - Pat


---
This SF.Net email is sponsored by: IBM Linux Tutorials
Free Linux tutorial presented by Daniel Robbins, President and CEO of
GenToo technologies. Learn everything from fundamentals to system
administration.http://ads.osdn.com/?ad_id=1470&alloc_id=3638&op=click
___
unattended-info mailing list
[EMAIL PROTECTED]
https://lists.sourceforge.net/lists/listinfo/unattended-info